@@ -12,7 +12,7 @@
 /*                                                                      */
 /* Dr Brian Gladman (gladman@seven77.demon.co.uk) 14th January 1999     */
 
-/* $Id: loki97.c,v 1.8 2001/05/17 18:44:59 nmav Exp $ */
+/* $Id: loki97.c,v 1.11 2001/09/09 09:52:54 nmav Exp $ */
 
 /* modified in order to use the libmcrypt API by Nikos Mavroyanopoulos 
  * All modifications are placed under the license of libmcrypt.
@@ -63,8 +63,9 @@ Mean:         2186 cycles =    11.7 mbits/sec
 */
 
 
-#include "../../lib/libdefs.h"
-#include "../../lib/mcrypt_modules.h"
+#include <libdefs.h>
+
+#include <mcrypt_modules.h>
 
 #ifdef USE_LTDL
 #define _mcrypt_set_key loki97_LTX__mcrypt_set_key
@@ -398,22 +399,18 @@ WIN32DLL_DEFINE int _mcrypt_get_key_size()
 {
 	return 32;
 }
-WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+
+static const int key_sizes[] = { 16, 24, 32 };
+WIN32DLL_DEFINE const int *_mcrypt_get_supported_key_sizes(int *len)
 {
-	int *size = malloc(3 * sizeof(int));
-	size[0] = 16;
-	size[1] = 24;
-	size[2] = 32;
-	*len = 3;
-	return size;
+	*len = sizeof(key_sizes)/sizeof(int);
+	return key_sizes;
+
 }
 
 WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
 {
-	char *x;
-	x = malloc(10);
-	strcpy(x, "LOKI97");
-	return x;
+return "LOKI97";
 }
 
 #define CIPHER "8cb28c958024bae27a94c698f96f12a9"
@@ -476,5 +473,5 @@ WIN32DLL_DEFINE int _mcrypt_self_test()
 
 WIN32DLL_DEFINE word32 _mcrypt_algorithm_version()
 {
-	return 19991129;
+	return 20010801;
 }
