@@ -16,10 +16,10 @@
  * All modifications are placed under the license of libmcrypt.
  */
 
-/* $Id: tripledes.c,v 1.7 2001/05/17 19:09:08 nmav Exp $ */
+/* $Id: tripledes.c,v 1.10 2001/09/09 09:52:55 nmav Exp $ */
 
-#include "../../lib/libdefs.h"
-#include "../../lib/mcrypt_modules.h"
+#include <libdefs.h>
+#include <mcrypt_modules.h>
 #include "tripledes.h"
 
 #ifdef USE_LTDL
@@ -769,19 +769,17 @@ WIN32DLL_DEFINE int _mcrypt_get_key_size()
 {
 	return 24;
 }
-WIN32DLL_DEFINE int *_mcrypt_get_supported_key_sizes(int *len)
+
+static const int key_sizes[] = { 24 };
+WIN32DLL_DEFINE const int *_mcrypt_get_supported_key_sizes(int *len)
 {
-	int *size = malloc(1 * sizeof(int));
-	size[0] = 24;
-	*len = 1;
-	return size;
+	*len = sizeof(key_sizes)/sizeof(int);
+	return key_sizes;
+
 }
-WIN32DLL_DEFINE char *_mcrypt_get_algorithms_name()
+WIN32DLL_DEFINE const char *_mcrypt_get_algorithms_name()
 {
-	char *x;
-	x = malloc(10);
-	strcpy(x, "3DES");
-	return x;
+	return "3DES";
 }
 
 #define CIPHER "58ed248f77f6b19e"
