@@ -22,7 +22,7 @@
 
 #ifdef USE_LTDL
 #define _init_mcrypt ofb_LTX__init_mcrypt
-#define _mcrypt_set_state cfb_LTX__mcrypt_set_state
+#define _mcrypt_set_state ofb_LTX__mcrypt_set_state
 #define _end_mcrypt ofb_LTX__end_mcrypt
 #define _mcrypt ofb_LTX__mcrypt
 #define _mdecrypt ofb_LTX__mdecrypt
@@ -102,7 +102,7 @@ void _end_mcrypt( OFB_BUFFER* buf) {
 
 
 int _mcrypt( OFB_BUFFER* buf,void *plaintext, int len, int blocksize, void* akey, void (*func)(void*,void*), void (*func2)(void*,void*) )
-{				/* plaintext is 1 byte (8bit cfb) */
+{				/* plaintext is 1 byte (8bit ofb) */
 	char *plain = plaintext;
 	int i, j;
 	void (*_mcrypt_block_encrypt) (void *, void *);
